.. role:: hidden
    :class: hidden-section

ax.early_stopping
===================================

.. automodule:: ax.early_stopping
.. currentmodule:: ax.early_stopping

Strategies
~~~~~~~~~~~~~~~~~~

.. automodule:: ax.early_stopping.strategies
    :members:
    :undoc-members:
    :show-inheritance:

Utils
~~~~~~~~~~~~~~~~~~

.. automodule:: ax.early_stopping.utils
    :members:
    :undoc-members:
    :show-inheritance:
